Index: app/gtk_dnd_util.h |
diff --git a/app/gtk_dnd_util.h b/app/gtk_dnd_util.h |
index f68931d77cb33191ec57deed700be86e87ddb4b9..578a0262690264b3361b4378f52f4145b086b1d3 100644 |
--- a/app/gtk_dnd_util.h |
+++ b/app/gtk_dnd_util.h |
@@ -78,9 +78,10 @@ bool ExtractNamedURL(GtkSelectionData* selection_data, |
bool ExtractURIList(GtkSelectionData* selection_data, |
std::vector<GURL>* urls); |
// Convenience method for converting between a web drag operation and the GDK |
// equivalent. |
GdkDragAction WebDragOpToGdkDragAction(WebKit::WebDragOperationsMask op); |
+WebKit::WebDragOperationsMask GdkDragActionToWebDragOp(GdkDragAction action); |
} // namespace gtk_dnd_util |
@@ -78,9 +78,10 @@ bool ExtractNamedURL(GtkSelectionData* selection_data, |
bool ExtractURIList(GtkSelectionData* selection_data, |
std::vector<GURL>* urls); |
-// Convenience method for converting between a web drag operation and the GDK |
+// Convenience methods for converting between web drag operations and the GDK |
// equivalent. |
GdkDragAction WebDragOpToGdkDragAction(WebKit::WebDragOperationsMask op); |